@@ -34,44 +34,13 @@
 
 K_PLUGIN_CLASS_WITH_JSON(KWalletConfig, "kwalletconfig.json")
 
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-KWalletConfig::KWalletConfig(QWidget *parent, const QVariantList &args)
-    : KCModule(parent, args)
-      , _wcw(new WalletConfigWidget(this))
-      , _cfg(KSharedConfig::openConfig(QStringLiteral("kwalletrc"), KConfig::NoGlobals))
-#else
 KWalletConfig::KWalletConfig(QObject *parent, const KPluginMetaData &data)
     : KCModule(parent, data)
       , _wcw(new WalletConfigWidget(widget()))
       , _cfg(KSharedConfig::openConfig(QStringLiteral("kwalletrc"), KConfig::NoGlobals))
-#endif
 {
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    auto about = new KAboutData(QStringLiteral("kcmkwallet5"),
-                                       i18n("KDE Wallet Control Module"),
-                                       QStringLiteral(KWALLETMANAGER_VERSION_STRING),
-                                       QString(),
-                                       KAboutLicense::GPL,
-                                       i18n("(c) 2003 George Staikos"));
-    about->addAuthor(i18n("George Staikos"),
-                     QString(),
-                     QStringLiteral("staikos@kde.org"));
-    setAboutData(about);
-#endif
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    setNeedsAuthorization(true);
-#else
-    setAuthActionName(QStringLiteral("org.kde.kcontrol.kcmkwallet5.save"));
-    // We need to make manually
-    m_authAction = KAuth::Action(QLatin1String("org.kde.kcontrol.kcmkwallet5.save"));
-    m_authAction.setHelperId(QStringLiteral("org.kde.kcontrol.kcmkwallet5"));
-    m_authAction.setParentWidget(widget());
-#endif
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    auto vbox = new QVBoxLayout(this);
-#else
+  setAuthActionName(QStringLiteral("org.kde.kcontrol.kcmkwallet5.save"));
     auto vbox = new QVBoxLayout(widget());
-#endif
     vbox->setContentsMargins(0, 0, 0, 0);
     vbox->addWidget(_wcw);
 
@@ -130,25 +99,14 @@ void KWalletConfig::updateWalletLists()
 QString KWalletConfig::newWallet()
 {
     bool ok;
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    const QString n = QInputDialog::getText(this, i18n("New Wallet"),
-                                            i18n("Please choose a name for the new wallet:"),
-                                            QLineEdit::Normal, QString(),
-                                            &ok);
-#else
     const QString n = QInputDialog::getText(widget(), i18n("New Wallet"),
                                             i18n("Please choose a name for the new wallet:"),
                                             QLineEdit::Normal, QString(),
                                             &ok);
-#endif
     if (!ok) {
         return {};
     }
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    KWallet::Wallet *w = KWallet::Wallet::openWallet(n, topLevelWidget()->winId());
-#else
     KWallet::Wallet *w = KWallet::Wallet::openWallet(n, widget()->topLevelWidget()->winId());
-#endif
     if (!w) {
         return {};
     }
@@ -167,11 +125,7 @@ void KWalletConfig::newLocalWallet()
     updateWalletLists();
 
     _wcw->_localWallet->setCurrentIndex(_wcw->_localWallet->findText(n));
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-        Q_EMIT changed(true);
-#else
         setNeedsSave(true);
-#endif
 }
 
 void KWalletConfig::newNetworkWallet()
@@ -184,11 +138,7 @@ void KWalletConfig::newNetworkWallet()
     updateWalletLists();
 
     _wcw->_defaultWallet->setCurrentIndex(_wcw->_defaultWallet->findText(n));
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-        Q_EMIT changed(true);
-#else
         setNeedsSave(true);
-#endif
 }
 
 void KWalletConfig::launchManager()
@@ -204,16 +154,12 @@ void KWalletConfig::launchManager()
 
 void KWalletConfig::configChanged()
 {
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-        Q_EMIT changed(true);
-#else
         setNeedsSave(true);
-#endif
 }
 
 void KWalletConfig::load()
 {
-    KConfigGroup config(_cfg, "Wallet");
+    KConfigGroup config(_cfg, QStringLiteral("Wallet"));
     _wcw->_enabled->setChecked(config.readEntry("Enabled", true));
     _wcw->_openPrompt->setChecked(config.readEntry("Prompt on Open", false));
     _wcw->_launchManager->setChecked(config.readEntry("Launch Manager", false));
@@ -244,8 +190,8 @@ void KWalletConfig::load()
         _wcw->_localWalletSelected->setChecked(false);
     }
     _wcw->_accessList->clear();
-    KConfigGroup ad(_cfg, "Auto Deny");
-    KConfigGroup aa(_cfg, "Auto Allow");
+    KConfigGroup ad(_cfg, QStringLiteral("Auto Deny"));
+    KConfigGroup aa(_cfg, QStringLiteral("Auto Allow"));
     QStringList denykeys = ad.entryMap().keys();
     const QStringList keys = aa.entryMap().keys();
     for (QStringList::const_iterator i = keys.begin(); i != keys.end(); ++i) {
@@ -256,10 +202,10 @@ void KWalletConfig::load()
         path.append(QStringLiteral("/kwalletd/%1.kwl").arg(walletName));
         if (!QFile::exists(path)) {
             // if the wallet no longer exists, delete the entries from the configuration file and skip to next entry
-            KConfigGroup cfgAllow = KSharedConfig::openConfig(QStringLiteral("kwalletrc"))->group("Auto Allow");
+            KConfigGroup cfgAllow = KSharedConfig::openConfig(QStringLiteral("kwalletrc"))->group(QStringLiteral("Auto Allow"));
             cfgAllow.deleteEntry(walletName);
 
-            KConfigGroup cfgDeny = KSharedConfig::openConfig(QStringLiteral("kwalletrc"))->group("Auto Deny");
+            KConfigGroup cfgDeny = KSharedConfig::openConfig(QStringLiteral("kwalletrc"))->group(QStringLiteral("Auto Deny"));
             cfgDeny.deleteEntry(walletName);
             continue;
         }
@@ -285,23 +231,19 @@ void KWalletConfig::load()
     }
     _wcw->_accessList->header()->setSectionResizeMode(QHeaderView::ResizeToContents);
 
-    KConfigGroup secretsAPIConfig(_cfg, "org.freedesktop.secrets");
+    KConfigGroup secretsAPIConfig(_cfg, QStringLiteral("org.freedesktop.secrets"));
     _wcw->_secretServiceAPI->setChecked(secretsAPIConfig.readEntry("apiEnabled", true));
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-        Q_EMIT changed(false);
-#else
         setNeedsSave(false);
-#endif
 }
 
 void KWalletConfig::save()
 {
     QVariantMap args;
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    KAuth::Action action = authAction();
-#else
-    KAuth::Action action = m_authAction;
-#endif
+    KAuth::Action action(QLatin1String("org.kde.kcontrol.kcmkwallet5.save"));
+    action.setHelperId(QStringLiteral("org.kde.kcontrol.kcmkwallet5"));
+
+    widget()->window()->winId();
+    action.setParentWindow(widget()->window()->windowHandle());
     if (!action.isValid()) {
         qDebug() << "There's no authAction, not saving settings";
         return;
@@ -311,24 +253,16 @@ void KWalletConfig::save()
     KAuth::ExecuteJob *j = action.execute();
 
     if (!j->exec()) {
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-        if (j->error() == KAuth::ActionReply::AuthorizationDeniedError) {
-            KMessageBox::error(this, i18n("Permission denied."), i18n("KDE Wallet Control Module"));
-        } else {
-            KMessageBox::error(this, i18n("Error while authenticating action:\n%1", j->errorString()), i18n("KDE Wallet Control Module"));
-        }
-#else
         if (j->error() == KAuth::ActionReply::AuthorizationDeniedError) {
             KMessageBox::error(widget(), i18n("Permission denied."), i18n("KDE Wallet Control Module"));
         } else {
             KMessageBox::error(widget(), i18n("Error while authenticating action:\n%1", j->errorString()), i18n("KDE Wallet Control Module"));
         }
-#endif
         load();
         return;
     }
 
-    KConfigGroup config(_cfg, "Wallet");
+    KConfigGroup config(_cfg, QStringLiteral("Wallet"));
     config.writeEntry("Enabled", _wcw->_enabled->isChecked());
     config.writeEntry("Launch Manager", _wcw->_launchManager->isChecked());
     config.writeEntry("Leave Manager Open", !_wcw->_autocloseManager->isChecked());
@@ -352,9 +286,9 @@ void KWalletConfig::save()
     }
 
     // FIXME: won't survive a language change
-    _cfg->deleteGroup("Auto Allow");
-    _cfg->deleteGroup("Auto Deny");
-    config  = _cfg->group("Auto Allow");
+    _cfg->deleteGroup(QStringLiteral("Auto Allow"));
+    _cfg->deleteGroup(QStringLiteral("Auto Deny"));
+    config  = _cfg->group(QStringLiteral("Auto Allow"));
     for (int i = 0; i < _wcw->_accessList->topLevelItemCount(); ++i) {
         QTreeWidgetItem *parentItem = _wcw->_accessList->topLevelItem(i);
         QStringList al;
@@ -367,7 +301,7 @@ void KWalletConfig::save()
         config.writeEntry(parentItem->text(0), al);
     }
 
-    config = _cfg->group("Auto Deny");
+    config = _cfg->group(QStringLiteral("Auto Deny"));
     for (int i = 0; i < _wcw->_accessList->topLevelItemCount(); ++i) {
         QTreeWidgetItem *parentItem = _wcw->_accessList->topLevelItem(i);
         QStringList al;
@@ -380,7 +314,7 @@ void KWalletConfig::save()
         config.writeEntry(parentItem->text(0), al);
     }
 
-    KConfigGroup secretsAPIConfig(_cfg, "org.freedesktop.secrets");
+    KConfigGroup secretsAPIConfig(_cfg, QStringLiteral("org.freedesktop.secrets"));
     secretsAPIConfig.writeEntry("apiEnabled", _wcw->_secretServiceAPI->isChecked());
 
     _cfg->sync();
@@ -393,11 +327,7 @@ void KWalletConfig::save()
         // this will eventually make kwalletd exit upon deactivation
         kwalletd.call(QStringLiteral("reconfigure"));
     }
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-        Q_EMIT changed(false);
-#else
         setNeedsSave(false);
-#endif
 }
 
 void KWalletConfig::defaults()
@@ -415,34 +345,16 @@ void KWalletConfig::defaults()
     _wcw->_localWallet->setCurrentIndex(0);
     _wcw->_accessList->clear();
     _wcw->_secretServiceAPI->setChecked(true);
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-        Q_EMIT changed(true);
-#else
         setNeedsSave(true);
-#endif
 }
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-QString KWalletConfig::quickHelp() const
-{
-    return i18n("This configuration module allows you to configure the KDE wallet system.");
-}
-#endif
 
 void KWalletConfig::customContextMenuRequested(const QPoint &pos)
 {
     QTreeWidgetItem *item = _wcw->_accessList->itemAt(pos);
     if (item && item->parent()) {
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-        auto m = new QMenu(this);
-#else
         auto m = new QMenu(widget());
-#endif
         m->setTitle(item->parent()->text(0));
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        m->addAction(i18n("&Delete"), this, &KWalletConfig::deleteEntry, Qt::Key_Delete);
-#else
         m->addAction(i18n("&Delete"), Qt::Key_Delete, this, &KWalletConfig::deleteEntry);
-#endif
         m->exec(_wcw->_accessList->mapToGlobal(pos));
         delete m;
     }
@@ -453,11 +365,7 @@ void KWalletConfig::deleteEntry()
     QList<QTreeWidgetItem *> items = _wcw->_accessList->selectedItems();
     if (items.count() == 1 && items[0]) {
         delete items[0];
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-        Q_EMIT changed(true);
-#else
         setNeedsSave(true);
-#endif
     }
 }
 
