@@ -25,16 +25,22 @@
  *  KWalletFolderItem - ListView items to represent kwallet folders
  */
 KWalletFolderItem::KWalletFolderItem(KWallet::Wallet *w, QTreeWidget *parent, const QString &name, int entries)
-    : QTreeWidgetItem(parent, KWalletFolderItemClass), _wallet(w), _name(name), _entries(entries)
+    : QTreeWidgetItem(parent, KWalletFolderItemClass), _wallet(w), _name(name), _entries(entries), m_services(KService::allServices())
 {
     setText(0, QStringLiteral("%1 (%2)").arg(_name).arg(_entries));
     setFlags(Qt::ItemIsSelectable | Qt::ItemIsDragEnabled | Qt::ItemIsDropEnabled | Qt::ItemIsEnabled);
     setIcon(0, getFolderIcon());
 }
 
-QIcon KWalletFolderItem::getFolderIcon()
+QIcon KWalletFolderItem::getFolderIcon() const
 {
-    return QIcon::fromTheme(_name, QIcon::fromTheme(_name.toLower(), QIcon::fromTheme(QStringLiteral("folder"))));
+    for (auto service : m_services) {
+        if (service->name().compare(_name, Qt::CaseSensitivity::CaseInsensitive) == 0 && !service->icon().isEmpty()) {
+            return QIcon::fromTheme(service->icon());
+        }
+    }
+
+    return QIcon::fromTheme(_name, QIcon::fromTheme(QStringLiteral("folder")));
 }
 
 void KWalletFolderItem::refresh()
@@ -76,12 +82,12 @@ KWalletContainerItem *KWalletFolderItem::getContainer(KWallet::Wallet::EntryType
     return nullptr;
 }
 
-bool KWalletFolderItem::contains(const QString &key)
+bool KWalletFolderItem::contains(const QString &key) const
 {
     return (getItem(key) != nullptr);
 }
 
-QTreeWidgetItem *KWalletFolderItem::getItem(const QString &key)
+QTreeWidgetItem *KWalletFolderItem::getItem(const QString &key) const
 {
     for (int i = 0; i < childCount(); ++i) {
         auto ci = dynamic_cast<KWalletContainerItem *>(child(i));
@@ -126,12 +132,12 @@ KWallet::Wallet::EntryType KWalletContainerItem::entryType()
     return _type;
 }
 
-bool KWalletContainerItem::contains(const QString &key)
+bool KWalletContainerItem::contains(const QString &key) const
 {
     return getItem(key) != nullptr;
 }
 
-QTreeWidgetItem *KWalletContainerItem::getItem(const QString &key)
+QTreeWidgetItem *KWalletContainerItem::getItem(const QString &key) const
 {
     for (int i = 0; i < childCount(); ++i) {
         auto entryItem = dynamic_cast<KWalletEntryItem *>(child(i));
@@ -598,7 +604,7 @@ void KWalletEntryList::dragMoveEvent(QDragMoveEvent *e)
     }
 }
 
-KWalletFolderItem *KWalletEntryList::getFolder(const QString &name)
+KWalletFolderItem *KWalletEntryList::getFolder(const QString &name) const
 {
     for (int i = 0; i < topLevelItemCount(); ++i) {
         auto fi = dynamic_cast<KWalletFolderItem *>(topLevelItem(i));
